#
# spec file for package libsigrokdecode
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libsigrokdecode
%define libname %{name}4
%define baseversion 0.6.0
Version:        0.6.0~git20241001.71f4514
Release:        1.1
Summary:        Protocol Decoders for sigrok
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://sigrok.org/
Source0:        %{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch0:         libsigrokdecode-versioned-decoders.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel >= 0.9.4
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel >= 2.24.0
BuildRequires:  libsigrok-devel >= 0.3.0
BuildRequires:  libtool
BuildRequires:  python3-devel >= 3.2

%description
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrokdecode is a shared library written in C which provides the basic
API for running sigrok protocol decoders. The protocol decoders themselves
are written in Python.

%package     -n %{libname}
Summary:        Protocol Decoder Library for sigrok
Group:          System/Libraries
Requires:       python3-base
# Fix screwup
Obsoletes:      %{libname} = 0.6.0+git20240304.0235970

%description -n %{libname}
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrokdecode is a shared library written in C which provides the basic
API for running sigrok protocol decoders. The protocol decoders themselves
are written in Python.

%package     -n libirmp0
Summary:        Protocol Decoder Library for sigrok
Group:          System/Libraries

%description -n libirmp0
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

%package        devel
Summary:        Protocol Decoder Library for sigrok
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       python3-devel

%description    devel
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

libsigrokdecode is a shared library written in C which provides the basic
API for running sigrok protocol decoders. The protocol decoders themselves
are written in Python.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
        --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{_datadir}/%{name}-%{baseversion}/

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post -n libirmp0 -p /sbin/ldconfig
%postun -n libirmp0 -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc README HACKING NEWS
%{_libdir}/libsig*.so.*
%{_datadir}/%{name}-%{baseversion}/

%files -n libirmp0
%{_libdir}/libirmp*.so.*
%license COPYING

%files devel
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*

%changelog
* Fri Apr 11 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix version, pre-versions *must* use ~ as a version delimiter.
  A + delimiter marks versions post release.
* Thu Apr  3 2025 Jiri Slaby <jslaby@suse.cz>
- Update to version libsigrokdecodeunreleased+git20241001.71f4514:
  * max72xx: Rename max7219 to max72xx and streamline PD
  * max7219: Add support for cascading MAX72xx chips
  * Fix escape sequences treated as unicode laterals
  * mcp230xx: Add an mcp230xx decoder
  * usb_power_delivery: Handle extended message type in PD 3.0
  * usb_packet: Handle truncated data packets.
  * pwm: Add frequency measurement
  * timing: Allow resetting counter on any edge
  * avr_isp: Add even more parts
- add %%fdupes and %%post for libirmp
- cleanup of .spec
* Sat Sep 14 2024 kkaempf@suse.de
- Update to version libsigrokdecode-0.6.0+git20240304.0235970:
  * avr_isp: Add more parts
  * avr_isp: fix crash if part name is not known
  * st25r39xx_spi: Fix FIFOR/FIFOW issues with PV's Tabular Output View
  * srd: drop deprecated PyEval_InitThreads() on Python 3.9+
  * spiflash: add MX25L8006 device type
  * sae_j1850_vpw: rewrite decoder to improve usability and maintenance
  * rgb_led_spi: adjust decoder implementation's Python style
  * rgb_led_ws281x: default to RGB[W] annotation text order
  * rgb_led_ws281x: emit annotations for individual colour components
  * rgb_led_ws281x: add developer comments, link to chip datasheets
- split off libirmp0
- drop 0001-Properly-detect-python-library-for-3.9.patch, upstream
* Mon Jun 27 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Python >= 3.9, add
  0001-Properly-detect-python-library-for-3.9.patch
* Wed Dec 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 0.5.3
  * New supported protocol decoders:
  - lin: Local Interconnect Network (LIN) protocol
  - x2444m: Xicor X2444M/P nonvolatile static RAM protocol
  - ds2408: 1-Wire 8-channel addressable switch
  - cc1101: Low-power sub-1GHz RF transceiver chip
  - enc28j60: Microchip ENC28J60 10Base-T Ethernet controller protocol
  - pca9571: NXP PCA9571 8-bit I²C output expander
  - seven_segment: 7-segment display protocol
  - amulet_ascii: Amulet Technologies LCD controller ASCII protocol
  - tdm_audio: TDM multi-channel audio protocol
  - signature: Annotate signature of logic patterns
  - nes_gamepad: NES gamepad button states
  - flexray: Automotive network communications protocol
  - ir_rc6: RC-6 infrared remote control protocol
  - ieee488: IEEE-488 General Purpose Interface Bus (GPIB/HPIB or IEC)
  - hdcp: HDCP protocol over HDMI
  * Several other improvements, see included NEWS file
  * The library API and ABI is compatible with version 0.5.2
* Wed Sep 12 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 0.5.2
  * New supported protocol decoders:
  - mcs48: Intel MCS-48 external memory access protocol
  - st7735: Sitronix ST7735 TFT controller protocol
  - atsha204a: Microchip ATSHA204A CryptoAuthentication device
  - cfp: 100 Gigabit C form-factor pluggable (CFP) protocol
  - jtag_ejtag: MIPS EJTAG protocol
  - swim: STM8 Single Wire Interface Module (SWIM) protocol
  - cec: HDMI Consumer Electronics Control (CEC) protocol
  - miller: Miller encoding protocol
  - ook: On-off keying protocol
  - ook_oregon: Oregon Scientific weather sensor protocol
  - ook_vis: OOK visualisation in various formats
  * Several other improvements, see included NEWS file
  * The library API and ABI is compatible with version 0.5.1
- Cleanup: remove %%defattr, use %%license
* Fri Apr 13 2018 stefan.bruens@rwth-aachen.de
- Update to 0.5.1
  * New (backported) supported protocol decoders:
  - ac97: Audio and modem control for PC systems
  - ds243x: Maxim DS243x series 1-Wire EEPROM protocol
  - maple_bus: Maple bus peripheral protocol for SEGA Dreamcast
  - morse: Demodulated morse code protocol
  - graycode: Accumulate rotary encoder increments, timing statistics
  - counter: Count number of edges
  - sda2506: Serial nonvolatile 1-Kbit EEPROM
  - rc_encode: PT2262/HX2262/SC5262 remote control encoder protocol
  * The library API and ABI is compatible with version 0.5.0
  * Support for the PD v2 API has been dropped. All PDs distributed
    with libsigrokdecode were converted to the new, query-based API.
* Sat Jul  1 2017 stefan.bruens@rwth-aachen.de
- Remove Obsoletes: libsigrokdecode3. Obsoletes implies a conflict,
  so there is no way in rpm to trigger deinstalation of deprecated
  shared library packages.
* Tue Jun 13 2017 stefan.bruens@rwth-aachen.de
- Update to 0.5.0
  * New supported protocol decoders:
  - ade77xx          Poly phase multifunction energy metering IC protocol
  - adf435x          Wideband synthesizer with integrated VCO
  - dali             DALI lighting control protocol
  - dsi              DSI lighting control protocol
  - eeprom93xx       93xx series Microwire EEPROM protocol (bug #931)
  - iec              Commodore serial IEEE-488 (IEC) bus protocol
  - microwire        3-wire, half-duplex, synchronous serial bus (bug #931)
  * Add support for the new query-based PD v3 decoder API.
* Mon Dec 26 2016 stefan.bruens@rwth-aachen.de
- Update to 0.4.1
  * New (backported) supported protocol decoders:
  - aud              Renesas/Hitachi Advanced User Debugger (AUD) protocol
  - avr_pdi          Atmel proprietary interface for the ATxmega MCU
  - dmx512           Professional lighting control protocol
  - em4305           EM4205/EM4305 100-150kHz RFID protocol
  - gpib             IEEE-488 GPIB / HPIB protocol
  - ps2              PS/2 keyboard/mouse interface
  - rgb_led_ws281x   RGB LED string protocol (WS281x)
  - ssi32            Synchronous Serial Interface (32bit) protocol
  - t55xx            T55xx 100-150kHz RFID protocol
  - wiegand          Wiegand interface for electronic entry systems
  * Introduce a decoders/common facility for code shared between PDs (bug #804).
  * Supply metadata to all stacked decoders, not just low-level ones (bug #664).
  * Various Doxygen/documentation improvements.
  * Factor out a srd_decoder_apiver() internal helper function.
  * srd_inst_decode(): Return SRD_ERR_ARG if unitsize is 0.
  * Print error messages when decoders fail load time checks (bug #704).
  * Fix multiple valgrind warnings (memory leaks and such).
  * Build system: Sort PD list alphabetically in "make install".
  * Enhancements to several PDs, see NEWS for details.
- Drop upstream 0001-Supply-metadata-to-stacked-decoders.patch
* Fri Feb 12 2016 stefan.bruens@rwth-aachen.de
- Propagate metadata (e.g. samplerate) to stacked decoders
  * Add 0001-Supply-metadata-to-stacked-decoders.patch
* Sat Jan 30 2016 stefan.bruens@rwth-aachen.de
- Update to 0.4.0
  * New supported protocol decoders:
  - adns5020:      Bidirectional command and data over an
    SPI-like protocol
  - am230x:        Aosong AM230x/DHTxx/RHTxx humidity/temperature
    sensor
  - arm_etmv3:     Decode ETM instruction trace packets
  - arm_itm:       Trace data from Cortex-M / ARMv7m ITM module
  - arm_tpiu:      Filter TPIU formatted trace data into separate
    streams
  - eeprom24xx:    24xx series I²C EEPROM protocol
  - em4100:        EM4100 100-150kHz RFID protocol
  - jitter:        Retrieves the timing jitter between two digital
    signals
  - max7219:       8-digit LED display driver
  - mdio:          Half-duplex sync serial bus for MII management
    (MAC/PHY)
  - modbus:        Modbus RTU protocol for industrial applications
  - mrf24j40:      IEEE 802.15.4 2.4 GHz RF tranceiver chip
  - nrf24l01:      2.4GHz transceiver chip
  - pwm:           Analog level encoded in duty cycle percentage
  - qi:            Async serial protocol for Qi charger receivers
  - rfm12:         HopeRF RFM12 wireless transceiver control
    protocol
  - sdcard_sd:     Secure Digital card (SD mode) low-level
    protocol
  - spdif:         Serial bus for connecting digital audio devices
  - stepper_motor: Absolute position and movement speed from
    step/dir
  - swd:           Two-wire protocol for debug access to ARM CPUs
  - tca6408a:      Texas Instruments TCA6408A 8-bit I²C I/O
    expander
  - timing:        Calculate time between edges
  - usb_power_delivery: USB Power Delivery protocol
  - usb_request:   USB (low-speed and full-speed)
    transaction/request protocol
* Fri Sep 25 2015 stefan.bruens@rwth-aachen.de
- Track GIT version (upcoming 0.4.0)
  * update libsigrokdecode-versioned-decoders.patch
* Tue Aug  4 2015 max@suse.com
- New version: 0.3.1:
  * This is mostly a bugfix-release, the C library API was not
    changed.
  * Improvements and bugfixes in existing protocol decoders.
  * New decoders: adns5020, am230x, arm_etmv3, arm_itm, arm_tpiu,
    eeprom24xx, jitter, mdio, mrf24j40, nrf24l01, pwm, rfm12,
    spdif, stepper_motor, swd, tca6408a, timing.
* Fri Oct 24 2014 dimstar@opensuse.org
- Add libsigrokdecode-versioned-decoders.patch: move decoders to
  a versioned subdirectory.
- Change RPM Group of the library package to System/Libraries.
* Thu Oct 23 2014 max@suse.com
- Keep the decoders under /usr/share/libsigrokdecode (unversioned)
  otherwise the library won't find them.
* Sun Aug  3 2014 dmitry_r@opensuse.org
- Change package license to GPL-3.0+ according to README
- Minor spec file cleanup
* Mon Jun  2 2014 bugs@vdm-design.de
- sync spec file with .spec from rmax
* Fri May 30 2014 bugs@vdm-design.de
- Update to 0.3.0
  * New supported protocol decoders:
  - guess_bitrate  Guess the bitrate/baudrate of a signal
  - ir_nec         NEC infrared remote control protocol
  - ir_rc5         RC-5 infrared remote control protocol
  - midi           Musical Instrument Digital Interface
  - parallel       Parallel synchronous bus decoder
  - rgb_led_spi    RGB LED string decoder (SPI)
  - xfp            10 Gigabit Small Form Factor Pluggable Module
  - z80            Zilog Z80 microprocessor disassembly
  * New features:
  - Support for annotation rows (groups of annotation classes to be shown together).
  - The new OUTPUT_BINARY facility allows PDs to output decoded data in various (file) formats (e.g. I²S output in WAV format, USB output in PCAP format for Wireshark, LCD controller output in PNG format for viewing, and so on).
  - The new OUTPUT_META facility allows PDs to report certain data points or events to the frontend, which can be used for various post-processing and statistics purposes (e.g. simple counts, average/mean values, min/max values, and more).
  - The protocol decoder API has changed, the API version is bumped to 2. Decoders using the old PD API no longer work with this library release.
  - A large amount of PD fixes have been done to improve the usability of all PDs when used with GUIs (long/short annotations for zoom-dependent display, corrected annotation sample numbers, use of annotation rows, and so on).
  - Various API improvements were also performed to allow for all the new features. You can take a look at the API docs for more details.
  - And of course all PDs and the library code have received quite a few bugfixes, as usual.
* Thu Jan 24 2013 max@suse.com
- Requires python3.
* Wed Jan 16 2013 max@suse.com
- Initial build from git snapshot.
